@@ -1,5 +1,5 @@
 import numpy as np
-import collections 
+import collections
 import itertools
 import copy
 from copy import deepcopy
@@ -8,6 +8,7 @@ try:
     # pip install python-fcl
     # pip install trimesh[easy]
     import fcl
+
     # import trimesh
 except BaseException:
     fcl = None
@@ -17,7 +18,8 @@ from pykin.utils.transform_utils import get_h_mat
 from pykin.utils.log_utils import create_logger
 from pykin.utils.kin_utils import ShellColors as sc
 
-logger = create_logger('Collision Manager', "debug")
+logger = create_logger("Collision Manager", "debug")
+
 
 class CollisionManager:
     """
@@ -29,14 +31,14 @@ class CollisionManager:
 
     def __init__(self, is_robot=False):
         if fcl is None:
-            raise ValueError('No FCL Available! Please install the python-fcl library')
-        
+            raise ValueError("No FCL Available! Please install the python-fcl library")
+
         self._objs = {}
         self._names = collections.defaultdict(lambda: None)
         self._manager = fcl.DynamicAABBTreeCollisionManager()
         self._manager.setup()
         self.filtered_link_names = set()
-        
+
         if is_robot:
             self.is_robot = is_robot
 
@@ -44,7 +46,7 @@ class CollisionManager:
     #     return deepcopy(self)
 
     def __repr__(self):
-        return 'pykin.collision.collision_manager.{}()'.format(type(self).__name__)
+        return "pykin.collision.collision_manager.{}()".format(type(self).__name__)
 
     def setup_robot_collision(self, robot, geom="collision"):
         """
@@ -56,7 +58,7 @@ class CollisionManager:
             geom (str): robot's geometry type name ("visual" or "collision")
         """
         if not self.is_robot:
-            raise ValueError('Check argument!! Is is_robot True?')
+            raise ValueError("Check argument!! Is is_robot True?")
         self.geom = geom
         self._filter_contact_names(robot, geom)
 
@@ -68,15 +70,19 @@ class CollisionManager:
         for name, transform in fk.items():
             if name in list(info.keys()):
                 if geom == "collision":
-                    h_mat = np.dot(transform.h_mat, robot.links[name].collision.offset.h_mat)
+                    h_mat = np.dot(
+                        transform.h_mat, robot.links[name].collision.offset.h_mat
+                    )
                     for param in info[name][2]:
                         self.add_object(name, info[name][1], param, h_mat)
                 else:
-                    h_mat = np.dot(transform.h_mat, robot.links[name].visual.offset.h_mat)
+                    h_mat = np.dot(
+                        transform.h_mat, robot.links[name].visual.offset.h_mat
+                    )
                     for param in info[name][2]:
                         self.add_object(name, info[name][1], param, h_mat)
 
-    def _filter_contact_names(self, robot, geom):      
+    def _filter_contact_names(self, robot, geom):
         """
         Filter contact names in the beginning
 
@@ -92,11 +98,7 @@ class CollisionManager:
         _, names = self.in_collision_internal(return_names=True)
         self.filtered_link_names = copy.deepcopy(names)
 
-    def add_object(self, 
-                   name, 
-                   gtype=None,
-                   gparam=None,
-                   h_mat=None):
+    def add_object(self, name, gtype=None, gparam=None, h_mat=None):
         """
         Add an object to the collision manager.
         If an object with the given name is already in the manager, replace it.
@@ -117,21 +119,20 @@ class CollisionManager:
             if h_mat.shape == (3,):
                 h_mat = get_h_mat(position=h_mat)
             else:
-                raise ValueError('transform must be (4,4)!')
+                raise ValueError("transform must be (4,4)!")
 
         if gtype == "mesh":
             geom = self._get_BVH(gparam)
         else:
             geom = self._get_geom(gtype, gparam)
-        
+
         t = fcl.Transform(h_mat[:3, :3], h_mat[:3, 3])
         o = fcl.CollisionObject(geom, t)
 
         # Add collision object to set
         if name in self._objs:
             self._manager.unregisterObject(self._objs[name])
-        self._objs[name] = {'obj': o,
-                            'geom': geom}
+        self._objs[name] = {"obj": o, "geom": geom}
         # store the name of the geometry
         self._names[id(geom)] = name
 
@@ -142,38 +143,38 @@ class CollisionManager:
         """
         Set the transform for one of the manager's objects.
         This replaces the prior transform.
-        
+
         Args:
             name (str): An identifier for the object already in the manager
             h_mat (np.array): A new homogeneous transform matrix for the object
         """
         if name is None:
             return
-            
+
         if name in self._objs:
-            o = self._objs[name]['obj']
+            o = self._objs[name]["obj"]
             o.setRotation(h_mat[:3, :3])
             o.setTranslation(h_mat[:3, 3])
             self._manager.update(o)
         else:
-            raise ValueError('{} not in collision manager!'.format(name))
+            raise ValueError("{} not in collision manager!".format(name))
 
     def remove_object(self, name):
         """
         Delete an object from the collision manager.
-        
+
         Args:
             name (str): The identifier for the object
         """
         if name in self._objs:
-            self._manager.unregisterObject(self._objs[name]['obj'])
-            self._manager.update(self._objs[name]['obj'])
+            self._manager.unregisterObject(self._objs[name]["obj"])
+            self._manager.update(self._objs[name]["obj"])
             # remove objects from _objs
-            geom_id = id(self._objs.pop(name)['geom'])
+            geom_id = id(self._objs.pop(name)["geom"])
             # remove names
             self._names.pop(geom_id)
         else:
-            logger.warn('{} not in collision manager!'.format(name))
+            logger.warn("{} not in collision manager!".format(name))
 
     def reset_all_object(self):
         """
@@ -189,9 +190,9 @@ class CollisionManager:
         Check if any pair of objects in the manager collide with one another.
 
         Args:
-            return_names (bool): If true, a set is returned containing the names 
+            return_names (bool): If true, a set is returned containing the names
                                  of all pairs of objects in collision.
-        
+
         Returns:
             is_collision (bool): True if a collision occurred between any pair of objects and False otherwise
             names (set of 2-tup): The set of pairwise collisions. Each tuple
@@ -200,8 +201,11 @@ class CollisionManager:
         """
         cdata = fcl.CollisionData()
         if return_names:
-            cdata = fcl.CollisionData(request=fcl.CollisionRequest(
-                    num_max_contacts=100000, enable_contact=True))
+            cdata = fcl.CollisionData(
+                request=fcl.CollisionRequest(
+                    num_max_contacts=100000, enable_contact=True
+                )
+            )
 
         self._manager.collide(cdata, fcl.defaultCollisionCallback)
 
@@ -209,8 +213,7 @@ class CollisionManager:
 
         objs_in_collision = set()
         for contact in cdata.result.contacts:
-            names = (self._extract_name(contact.o1),
-                        self._extract_name(contact.o2))
+            names = (self._extract_name(contact.o1), self._extract_name(contact.o2))
             names = tuple(sorted(names))
             if (names[0], names[1]) in self.filtered_link_names:
                 continue
@@ -226,14 +229,14 @@ class CollisionManager:
         else:
             return result
 
-    def in_collision_other(self, other_manager=None, return_names=False): 
+    def in_collision_other(self, other_manager=None, return_names=False):
         """
         Check if any object from this manager collides with any object
         from another manager.
 
         Args:
             other_manager (CollisionManager): Another collision manager object
-            return_names (bool): If true, a set is returned containing the names 
+            return_names (bool): If true, a set is returned containing the names
                                  of all pairs of objects in collision.
         Returns:
             is_collision (bool): True if a collision occurred between any pair of objects and False otherwise
@@ -242,31 +245,40 @@ class CollisionManager:
                                   second from the other_manager) indicating
                                   that the two corresponding objects are in collision.
         """
-        
+
         if other_manager is None:
             if return_names:
                 return None, None
             return None
-            
+
         cdata = fcl.CollisionData()
         if return_names:
-            cdata = fcl.CollisionData(request=fcl.CollisionRequest(
-                num_max_contacts=100000, enable_contact=False))
+            cdata = fcl.CollisionData(
+                request=fcl.CollisionRequest(
+                    num_max_contacts=100000, enable_contact=False
+                )
+            )
+
+        self._manager.collide(
+            other_manager._manager, cdata, fcl.defaultCollisionCallback
+        )
 
-        self._manager.collide(other_manager._manager,
-                              cdata,
-                              fcl.defaultCollisionCallback)
-        
         result = cdata.result.is_collision
 
         objs_in_collision = set()
 
         for contact in cdata.result.contacts:
-            coll_names = (self._extract_name(contact.o1), other_manager._extract_name(contact.o2))
+            coll_names = (
+                self._extract_name(contact.o1),
+                other_manager._extract_name(contact.o2),
+            )
             if (coll_names[0], coll_names[1]) in self.filtered_link_names:
                 continue
             if coll_names[0] is None:
-                coll_names = (self._extract_name(contact.o2), other_manager._extract_name(contact.o1))
+                coll_names = (
+                    self._extract_name(contact.o2),
+                    other_manager._extract_name(contact.o1),
+                )
 
             if return_names:
                 objs_in_collision.add(coll_names)
@@ -289,22 +301,24 @@ class CollisionManager:
         for (o1, o2) in list(itertools.permutations(self._objs, 2)):
             if (o1, o2) in self.filtered_link_names:
                 continue
-            distance = np.round(fcl.distance(self._objs[o1]['obj'],self._objs[o2]['obj'], req, res), 6)
+            distance = np.round(
+                fcl.distance(self._objs[o1]["obj"], self._objs[o2]["obj"], req, res), 6
+            )
             result[(o1, o2)] = distance
-        
+
         return result
 
     def get_distances_other(self, other_manager):
         """
         Get the minimum distance between any pair of objects, one in each manager.
-        
+
         Args:
             other_manager (CollisionManager): Another collision manager object
 
         Returns:
             distance (float): The min distance between a pair of objects, one from each manager.
         """
-        
+
         def _mix_objects():
             for o1 in self._objs:
                 for o2 in other_manager._objs:
@@ -312,12 +326,17 @@ class CollisionManager:
 
         req = fcl.DistanceRequest()
         res = fcl.DistanceResult()
-        
+
         result = collections.defaultdict(float)
         for (o1, o2) in _mix_objects():
-            distance = np.round(fcl.distance(self._objs[o1]['obj'], other_manager._objs[o2]['obj'], req, res), 6)
+            distance = np.round(
+                fcl.distance(
+                    self._objs[o1]["obj"], other_manager._objs[o2]["obj"], req, res
+                ),
+                6,
+            )
             result[(o1, o2)] = distance
-        
+
         return result
 
     def get_collision_info(self):
@@ -329,7 +348,10 @@ class CollisionManager:
         """
         col_info = {}
         for name, info in self._objs.items():
-            T = get_h_mat(position=info["obj"].getTranslation(), orientation=info["obj"].getRotation())
+            T = get_h_mat(
+                position=info["obj"].getTranslation(),
+                orientation=info["obj"].getRotation(),
+            )
             col_info[name] = T
         return col_info
 
@@ -340,10 +362,10 @@ class CollisionManager:
         Args:
             name (str)
         """
-        print(f"*"*20 + f" {sc.OKGREEN}{name} Collision Info{sc.ENDC} "+ f"*"*20)
+        print(f"*" * 20 + f" {sc.OKGREEN}{name} Collision Info{sc.ENDC} " + f"*" * 20)
         for name, info in self.get_collision_info().items():
             print(name, info[:3, 3])
-        print(f"*"*63 + "\n")
+        print(f"*" * 63 + "\n")
 
     def _get_BVH(self, mesh):
         """
@@ -370,10 +392,8 @@ class CollisionManager:
             bvh (fcl.BVHModel): BVH of input geometry
         """
         bvh = fcl.BVHModel()
-        bvh.beginModel(num_tris_=len(mesh.faces),
-                    num_vertices_=len(mesh.vertices))
-        bvh.addSubModel(verts=mesh.vertices,
-                        triangles=mesh.faces)
+        bvh.beginModel(num_tris_=len(mesh.faces), num_vertices_=len(mesh.vertices))
+        bvh.addSubModel(verts=mesh.vertices, triangles=mesh.faces)
         bvh.endModel()
         return bvh
 
@@ -381,10 +401,10 @@ class CollisionManager:
     def _get_geom(gtype, gparam):
         """
         Get fcl geometry from robot's geometry type or params
-        
+
         Args:
             geom (CollisionObject): Input model
-        
+
         Returns:
             names (hashable): Name of input geometry
         """
@@ -407,11 +427,11 @@ class CollisionManager:
         """
         Retrieve the name of an object from the manager by its
         CollisionObject, or return None if not found.
-        
+
         Args:
             geom (CollisionObject): Input model
-        
+
         Returns:
             names (hashable): Name of input geometry
         """
-        return self._names[id(geom)]
\ No newline at end of file
+        return self._names[id(geom)]
