@@ -5,7 +5,7 @@ from pykin.robots.bimanual import Bimanual
 from pykin.kinematics import jacobian as jac
 
 
-file_path = 'urdf/baxter/baxter.urdf'
+file_path = "urdf/baxter/baxter.urdf"
 robot = Bimanual(file_path, t_utils.Transform(rot=[0.0, 0.0, 0.0], pos=[0, 0, 0]))
 
 left_arm_thetas = np.zeros(15)
@@ -19,4 +19,4 @@ for arm in robot.arm_type:
     if robot.eef_name[arm]:
         J[arm] = jac.calc_jacobian(robot.desired_frames[arm], fk, len(np.zeros(7)))
 
-print(J)
\ No newline at end of file
+print(J)
