@@ -9,7 +9,7 @@ from pykin.utils.kin_utils import apply_robot_to_scene
 
 current_file_path = os.path.abspath(os.path.dirname(__file__))
 
-file_path = 'urdf/doosan/doosan_a0509_blue.urdf'
+file_path = "urdf/doosan/doosan_a0509_blue.urdf"
 robot = SingleArm(file_path, Transform(rot=[0.0, 0.0, 0.0], pos=[0, 0, 0.913]))
 
 c_manager = CollisionManager(is_robot=True)
@@ -17,9 +17,9 @@ c_manager.setup_robot_collision(robot, geom="visual")
 c_manager.show_collision_info()
 robot.setup_link_name("base_0", "link6")
 
-goal_qpos = np.array([ 0,  0, 0, 0,  0,  0])
+goal_qpos = np.array([0, 0, 0, 0, 0, 0])
 robot.set_transform(goal_qpos)
-    
+
 scene = trimesh.Scene()
 scene = apply_robot_to_scene(trimesh_scene=scene, robot=robot, geom=c_manager.geom)
-scene.show()
\ No newline at end of file
+scene.show()
