@@ -66,20 +66,34 @@ if not hasattr(__builtins__, "xrange"):
 
 # Changes with the original implementation at lines 452-460
 class TrustRegions(Solver):
-    (NEGATIVE_CURVATURE, EXCEEDED_TR, REACHED_TARGET_LINEAR,
-     REACHED_TARGET_SUPERLINEAR, MAX_INNER_ITER, MODEL_INCREASED) = range(6)
+    (
+        NEGATIVE_CURVATURE,
+        EXCEEDED_TR,
+        REACHED_TARGET_LINEAR,
+        REACHED_TARGET_SUPERLINEAR,
+        MAX_INNER_ITER,
+        MODEL_INCREASED,
+    ) = range(6)
     TCG_STOP_REASONS = {
         NEGATIVE_CURVATURE: "negative curvature",
         EXCEEDED_TR: "exceeded trust region",
         REACHED_TARGET_LINEAR: "reached target residual-kappa (linear)",
-        REACHED_TARGET_SUPERLINEAR: "reached target residual-theta "
-                                    "(superlinear)",
+        REACHED_TARGET_SUPERLINEAR: "reached target residual-theta " "(superlinear)",
         MAX_INNER_ITER: "maximum inner iterations",
-        MODEL_INCREASED: "model increased"
+        MODEL_INCREASED: "model increased",
     }
 
-    def __init__(self, miniter=3, kappa=0.1, theta=1.0, rho_prime=0.1,
-                 use_rand=False, rho_regularization=1e3, *args, **kwargs):
+    def __init__(
+        self,
+        miniter=3,
+        kappa=0.1,
+        theta=1.0,
+        rho_prime=0.1,
+        use_rand=False,
+        rho_regularization=1e3,
+        *args,
+        **kwargs
+    ):
         """
         Trust regions algorithm based on trustregions.m from the
         Manopt MATLAB package.
@@ -96,8 +110,9 @@ class TrustRegions(Solver):
         self.use_rand = use_rand
         self.rho_regularization = rho_regularization
 
-    def solve(self, problem, x=None, mininner=1, maxinner=None,
-              Delta_bar=None, Delta0=None):
+    def solve(
+        self, problem, x=None, mininner=1, maxinner=None, Delta_bar=None, Delta0=None
+    ):
         man = problem.manifold
         verbosity = problem.verbosity
 
@@ -147,8 +162,7 @@ class TrustRegions(Solver):
         if verbosity >= 1:
             print("Optimizing...")
         if verbosity >= 2:
-            print("{:44s}f: {:+.6e}   |grad|: {:.6e}".format(
-                " ", float(fx), norm_grad))
+            print("{:44s}f: {:+.6e}   |grad|: {:.6e}".format(" ", float(fx), norm_grad))
 
         self._start_optlog()
 
@@ -170,8 +184,16 @@ class TrustRegions(Solver):
 
             # Solve TR subproblem approximately
             eta, Heta, numit, stop_inner = self._truncated_conjugate_gradient(
-                problem, x, fgradx, eta, Delta, self.theta, self.kappa,
-                mininner, maxinner)
+                problem,
+                x,
+                fgradx,
+                eta,
+                Delta,
+                self.theta,
+                self.kappa,
+                mininner,
+                maxinner,
+            )
 
             srstr = self.TCG_STOP_REASONS[stop_inner]
 
@@ -189,7 +211,7 @@ class TrustRegions(Solver):
                 if g_Hg <= 0:
                     tau_c = 1
                 else:
-                    tau_c = min(norm_grad ** 3 / (Delta * g_Hg), 1)
+                    tau_c = min(norm_grad**3 / (Delta * g_Hg), 1)
 
                 # and generate the Cauchy point.
                 eta_c = -tau_c * Delta / norm_grad * fgradx
@@ -197,10 +219,10 @@ class TrustRegions(Solver):
 
                 # Now that we have computed the Cauchy point in addition to the
                 # returned eta, we might as well keep the best of them.
-                mdle = (fx + man.inner(x, fgradx, eta) +
-                        0.5 * man.inner(x, Heta, eta))
-                mdlec = (fx + man.inner(x, fgradx, eta_c) +
-                         0.5 * man.inner(x, Heta_c, eta_c))
+                mdle = fx + man.inner(x, fgradx, eta) + 0.5 * man.inner(x, Heta, eta)
+                mdlec = (
+                    fx + man.inner(x, fgradx, eta_c) + 0.5 * man.inner(x, Heta_c, eta_c)
+                )
                 if mdlec < mdle:
                     eta = eta_c
                     Heta = Heta_c
@@ -278,7 +300,7 @@ class TrustRegions(Solver):
             # The current strategy is that, if this should happen, then we
             # reject the step and reduce the trust region radius. This also
             # ensures that the actual cost values are monotonically decreasing.
-            model_decreased = (rhoden >= 0)
+            model_decreased = rhoden >= 0
 
             if not model_decreased:
                 srstr = srstr + ", model did not decrease"
@@ -292,8 +314,9 @@ class TrustRegions(Solver):
                 # stagnation in this "corner case" (NaN's really aren't
                 # supposed to occur, but it's nice if we can handle them
                 # nonetheless).
-                print("rho is NaN! Forcing a radius decrease. This should "
-                      "not happen.")
+                print(
+                    "rho is NaN! Forcing a radius decrease. This should " "not happen."
+                )
                 rho = np.nan
 
             # Choose the new TR radius based on the model performance
@@ -307,31 +330,38 @@ class TrustRegions(Solver):
                 consecutive_TRminus = consecutive_TRminus + 1
                 if consecutive_TRminus >= 5 and verbosity >= 1:
                     consecutive_TRminus = -np.inf
-                    print(" +++ Detected many consecutive TR- (radius "
-                          "decreases).")
-                    print(" +++ Consider decreasing options.Delta_bar "
-                          "by an order of magnitude.")
-                    print(" +++ Current values: Delta_bar = {:g} and "
-                          "Delta0 = {:g}".format(Delta_bar, Delta0))
+                    print(" +++ Detected many consecutive TR- (radius " "decreases).")
+                    print(
+                        " +++ Consider decreasing options.Delta_bar "
+                        "by an order of magnitude."
+                    )
+                    print(
+                        " +++ Current values: Delta_bar = {:g} and "
+                        "Delta0 = {:g}".format(Delta_bar, Delta0)
+                    )
             # If the actual decrease is at least 3/4 of the precicted decrease
             # and the tCG (inner solve) hit the TR boundary, increase the TR
             # radius. We also keep track of the number of consecutive
             # trust-region radius increases. If there are many, this may
             # indicate the need to adapt the initial and maximum radii.
-            elif rho > 3.0 / 4 and (stop_inner == self.NEGATIVE_CURVATURE or
-                                    stop_inner == self.EXCEEDED_TR):
+            elif rho > 3.0 / 4 and (
+                stop_inner == self.NEGATIVE_CURVATURE or stop_inner == self.EXCEEDED_TR
+            ):
                 trstr = "TR+"
                 Delta = min(2 * Delta, Delta_bar)
                 consecutive_TRminus = 0
                 consecutive_TRplus = consecutive_TRplus + 1
                 if consecutive_TRplus >= 5 and verbosity >= 1:
                     consecutive_TRplus = -np.inf
-                    print(" +++ Detected many consecutive TR+ (radius "
-                          "increases).")
-                    print(" +++ Consider increasing options.Delta_bar "
-                          "by an order of magnitude.")
-                    print(" +++ Current values: Delta_bar = {:g} and "
-                          "Delta0 = {:g}.".format(Delta_bar, Delta0))
+                    print(" +++ Detected many consecutive TR+ (radius " "increases).")
+                    print(
+                        " +++ Consider increasing options.Delta_bar "
+                        "by an order of magnitude."
+                    )
+                    print(
+                        " +++ Current values: Delta_bar = {:g} and "
+                        "Delta0 = {:g}.".format(Delta_bar, Delta0)
+                    )
             else:
                 # Otherwise, keep the TR radius constant.
                 consecutive_TRplus = 0
@@ -355,38 +385,41 @@ class TrustRegions(Solver):
 
             # ** Display:
             if verbosity == 2:
-                print("{:.3s} {:.3s}   k: {:5d}     num_inner: "
-                      "{:5d}     f: {:+e}   |grad|: {:e}   "
-                      "{:s}".format(accstr, trstr, k, numit,
-                                    float(fx), norm_grad, srstr))
+                print(
+                    "{:.3s} {:.3s}   k: {:5d}     num_inner: "
+                    "{:5d}     f: {:+e}   |grad|: {:e}   "
+                    "{:s}".format(accstr, trstr, k, numit, float(fx), norm_grad, srstr)
+                )
             elif verbosity > 2:
                 if self.use_rand and used_cauchy:
                     print("USED CAUCHY POINT")
-                print("{:.3s} {:.3s}    k: {:5d}     num_inner: "
-                      "{:5d}     {:s}".format(accstr, trstr, k, numit, srstr))
-                print("       f(x) : {:+e}     |grad| : "
-                      "{:e}".format(fx, norm_grad))
+                print(
+                    "{:.3s} {:.3s}    k: {:5d}     num_inner: "
+                    "{:5d}     {:s}".format(accstr, trstr, k, numit, srstr)
+                )
+                print("       f(x) : {:+e}     |grad| : " "{:e}".format(fx, norm_grad))
                 print("        rho : {:e}".format(rho))
 
             # ** CHECK STOPPING criteria
             stop_reason = self._check_stopping_criterion(
-                time0, gradnorm=norm_grad, iter=k)
+                time0, gradnorm=norm_grad, iter=k
+            )
 
             if stop_reason:
                 if verbosity >= 1:
                     print(stop_reason)
-                    print('')
+                    print("")
                 break
 
         if self._logverbosity <= 0:
             return x
         else:
-            self._stop_optlog(x, fx, stop_reason, time0,
-                              gradnorm=norm_grad, iter=k)
+            self._stop_optlog(x, fx, stop_reason, time0, gradnorm=norm_grad, iter=k)
             return x, self._optlog
 
-    def _truncated_conjugate_gradient(self, problem, x, fgradx, eta, Delta,
-                                      theta, kappa, mininner, maxinner):
+    def _truncated_conjugate_gradient(
+        self, problem, x, fgradx, eta, Delta, theta, kappa, mininner, maxinner
+    ):
         man = problem.manifold
         inner = man.inner
         hess = problem.hess
@@ -434,6 +467,7 @@ class TrustRegions(Solver):
 
         def model_fun(eta, Heta):
             return inner(x, eta, fgradx) + 0.5 * inner(x, eta, Heta)
+
         if not self.use_rand:
             model_value = 0
         else:
@@ -456,7 +490,7 @@ class TrustRegions(Solver):
                 alpha = z_r / d_Hd
                 # <neweta,neweta>_P =
                 # <eta,eta>_P + 2*alpha*<eta,delta>_P + alpha*alpha*<delta,delta>_P
-                e_Pe_new = e_Pe + 2 * alpha * e_Pd + alpha ** 2 * d_Pd
+                e_Pe_new = e_Pe + 2 * alpha * e_Pd + alpha**2 * d_Pd
             else:
                 e_Pe_new = e_Pe
 
@@ -467,15 +501,15 @@ class TrustRegions(Solver):
                 #  ee = <eta,eta>_prec,x
                 #  ed = <eta,delta>_prec,x
                 #  dd = <delta,delta>_prec,x
-                tmp = e_Pd * e_Pd + d_Pd * (Delta ** 2 - e_Pe)
-                if tmp > 0.:
-                    tau = ((-e_Pd +
-                            np.sqrt(e_Pd * e_Pd +
-                                    d_Pd * (Delta ** 2 - e_Pe))) / d_Pd)
+                tmp = e_Pd * e_Pd + d_Pd * (Delta**2 - e_Pe)
+                if tmp > 0.0:
+                    tau = (
+                        -e_Pd + np.sqrt(e_Pd * e_Pd + d_Pd * (Delta**2 - e_Pe))
+                    ) / d_Pd
 
                 # Check against NaNs (due to numerical errors in tmp)
                 else:
-                    tau = 0.
+                    tau = 0.0
 
                 eta = eta + tau * delta
 
@@ -533,10 +567,9 @@ class TrustRegions(Solver):
             # criterion on the r's (the gradients) or on the z's (the
             # preconditioned gradients). [CGT2000], page 206, mentions both as
             # acceptable criteria.
-            if (j >= mininner and
-               norm_r <= norm_r0 * min(norm_r0**theta, kappa)):
+            if j >= mininner and norm_r <= norm_r0 * min(norm_r0**theta, kappa):
                 # Residual is small enough to quit
-                if kappa < norm_r0 ** theta:
+                if kappa < norm_r0**theta:
                     stop_tCG = self.REACHED_TARGET_LINEAR
                 else:
                     stop_tCG = self.REACHED_TARGET_SUPERLINEAR
