@@ -10,11 +10,11 @@ import torch
 if torch.cuda.is_available():
     device = torch.cuda.current_device()
 else:
-    device = 'cpu'
+    device = "cpu"
 
 
 def jacobi_theta_function3(z, q, serie_nb_terms=200):
     function_value = torch.zeros_like(z).to(device)
-    for n in range(1, 1+serie_nb_terms):
-        function_value += torch.pow(q, n**2) * torch.cos(2*n*z)
-    return 2 * function_value + 1.
\ No newline at end of file
+    for n in range(1, 1 + serie_nb_terms):
+        function_value += torch.pow(q, n**2) * torch.cos(2 * n * z)
+    return 2 * function_value + 1.0
